@@ -50,4 +50,17 @@ def tellTime():
 
 def openMail():
     webbrowser.open('mailto:', new=1)
-    speak("I opened your mail for you.")
\ No newline at end of file
+    speak("I opened your mail for you.")
+
+def calculate(expression):
+    try:
+        result = eval(expression)
+        return str(result)
+    except:
+        return "Sorry, I couldn't perform that calculation"
+
+
+def voiceCalc():
+    expression = takeCommand()
+    result = calculate(expression)
+    speak(f"{result}")
\ No newline at end of file
